@@ -1,4 +1,3 @@
-static const char rcsid[]="$Id: lib.c,v 2.2 1999/01/02 09:11:35 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -480,6 +479,7 @@ void mutt_free_envelope (ENVELOPE **p)
   rfc822_free_address (&(*p)->mail_followup_to);
   safe_free ((void **) &(*p)->subject);
   safe_free ((void **) &(*p)->message_id);
+  safe_free ((void **) &(*p)->supersedes);
   safe_free ((void **) &(*p)->date);
   mutt_free_list (&(*p)->references);
   mutt_free_list (&(*p)->userhdrs);
@@ -766,7 +766,7 @@ FILE *safe_fopen (const char *path, const char *mode)
 
 /* return 0 on success, -1 on error */
 int mutt_check_overwrite (const char *attname, const char *path,
-				char *fname, size_t flen, int flags) 
+				char *fname, size_t flen, int *append) 
 {
   char tmp[_POSIX_PATH_MAX];
   struct stat st;
@@ -791,12 +791,22 @@ int mutt_check_overwrite (const char *attname, const char *path,
     else
       snprintf (fname, flen, "%s/%s", path, attname);
   }
-
-  if (flags != M_SAVE_APPEND &&
-      access (fname, F_OK) == 0 && 
-      mutt_yesorno (_("File exists, overwrite?"), 0) != 1)
-    return (-1);
   
+  if (*append == 0 && access (fname, F_OK) == 0)
+  {
+    switch (mutt_multi_choice
+	    (_("File exists, (o)verwrite, (a)ppend, or (c)ancel?"), _("oac")))
+    {
+      case -1: /* abort */
+      case 3:  /* cancel */
+	return -1;
+
+      case 2: /* append */
+        *append = M_SAVE_APPEND;
+      case 1: /* overwrite */
+	;
+    }
+  }
   return 0;
 }
 
@@ -858,15 +868,15 @@ void mutt_safe_path (char *s, size_t l, ADDRESS *a)
       *p = '_';
 }
 
-static char safe_chars[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+@{}._-:%";
+static char safe_chars[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+@{}._-:%/";
 
-void mutt_sanitize_filename(char *f)
+void mutt_sanitize_filename(char *f, short slash)
 {
   if(!f) return;
 
   for(; *f; f++)
   {
-    if(!strchr(safe_chars, *f))
+    if((slash && *f == '/') || !strchr(safe_chars, *f))
       *f = '_';
   }
 }
@@ -1221,7 +1231,7 @@ char *mutt_quote_filename(const char *f)
   
   for(i = 0, l = 3; f[i]; i++, l++)
   {
-    if(f[i] == '\'')
+    if(f[i] == '\'' || f[i] == '`')
       l += 3;
   }
   
@@ -1232,11 +1242,11 @@ char *mutt_quote_filename(const char *f)
   
   for(i = 0; f[i]; i++)
   {
-    if(f[i] == '\'')
+    if(f[i] == '\'' || f[i] == '`')
     {
       d[l++] = '\'';
       d[l++] = '\\';
-      d[l++] = '\'';
+      d[l++] = f[i];
       d[l++] = '\'';
     }
     else
